@@ -1,17 +1,16 @@
-use crate::commands::command::whole_stream_command;
-use crate::commands::run_alias::AliasCommand;
+use std::sync::atomic::Ordering;
+
 use crate::commands::UnevaluatedCallInfo;
 use crate::prelude::*;
 use log::{log_enabled, trace};
 use nu_errors::ShellError;
 use nu_protocol::hir::{ExternalRedirection, InternalCommand};
-use nu_protocol::{CommandAction, Primitive, ReturnSuccess, Scope, UntaggedValue, Value};
+use nu_protocol::{CommandAction, Primitive, ReturnSuccess, UntaggedValue, Value};
 
 pub(crate) async fn run_internal_command(
     command: InternalCommand,
-    context: &mut EvaluationContext,
+    context: &EvaluationContext,
     input: InputStream,
-    scope: Arc<Scope>,
 ) -> Result<InputStream, ShellError> {
     if log_enabled!(log::Level::Trace) {
         trace!(target: "nu::run::internal", "->");
@@ -19,10 +18,13 @@ pub(crate) async fn run_internal_command(
     }
 
     let objects: InputStream = trace_stream!(target: "nu::trace_stream::internal", "input" = input);
-    let internal_command = context.expect_command(&command.name);
+
+    let internal_command = context.scope.expect_command(&command.name);
 
     if command.name == "autoenv untrust" {
-        context.user_recently_used_autoenv_untrust = true;
+        context
+            .user_recently_used_autoenv_untrust
+            .store(true, Ordering::SeqCst);
     }
 
     let result = {
@@ -31,14 +33,12 @@ pub(crate) async fn run_internal_command(
                 internal_command?,
                 Tag::unknown_anchor(command.name_span),
                 command.args.clone(),
-                scope.clone(),
                 objects,
             )
             .await?
     };
 
     let head = Arc::new(command.args.head.clone());
-    //let context = Arc::new(context.clone());
     let context = context.clone();
     let command = Arc::new(command);
 
@@ -47,26 +47,24 @@ pub(crate) async fn run_internal_command(
             .then(move |item| {
                 let head = head.clone();
                 let command = command.clone();
-                let mut context = context.clone();
-                let scope = scope.clone();
+                let context = context.clone();
                 async move {
                     match item {
                         Ok(ReturnSuccess::Action(action)) => match action {
                             CommandAction::ChangePath(path) => {
                                 context.shell_manager.set_path(path);
-                                InputStream::from_stream(futures::stream::iter(vec![]))
+                                InputStream::empty()
                             }
                             CommandAction::Exit => std::process::exit(0), // TODO: save history.txt
                             CommandAction::Error(err) => {
-                                context.error(err.clone());
-                                InputStream::one(UntaggedValue::Error(err).into_untagged_value())
+                                context.error(err);
+                                InputStream::empty()
                             }
                             CommandAction::AutoConvert(tagged_contents, extension) => {
                                 let contents_tag = tagged_contents.tag.clone();
                                 let command_name = format!("from {}", extension);
                                 let command = command.clone();
-                                if let Some(converter) = context.registry.get_command(&command_name)
-                                {
+                                if let Some(converter) = context.scope.get_command(&command_name) {
                                     let new_args = RawCommandArgs {
                                         host: context.host.clone(),
                                         ctrl_c: context.ctrl_c.clone(),
@@ -81,14 +79,11 @@ pub(crate) async fn run_internal_command(
                                                 external_redirection: ExternalRedirection::Stdout,
                                             },
                                             name_tag: Tag::unknown_anchor(command.name_span),
-                                            scope,
                                         },
+                                        scope: context.scope.clone(),
                                     };
                                     let result = converter
-                                        .run(
-                                            new_args.with_input(vec![tagged_contents]),
-                                            &context.registry,
-                                        )
+                                        .run(new_args.with_input(vec![tagged_contents]))
                                         .await;
 
                                     match result {
@@ -122,8 +117,8 @@ pub(crate) async fn run_internal_command(
 
                                             futures::stream::iter(output).to_input_stream()
                                         }
-                                        Err(e) => {
-                                            context.add_error(e);
+                                        Err(err) => {
+                                            context.error(err);
                                             InputStream::empty()
                                         }
                                     }
@@ -139,13 +134,12 @@ pub(crate) async fn run_internal_command(
                                     context.shell_manager.insert_at_current(Box::new(
                                         match HelpShell::for_command(
                                             UntaggedValue::string(cmd).into_value(tag),
-                                            &context.registry(),
+                                            &context.scope,
                                         ) {
                                             Ok(v) => v,
                                             Err(err) => {
-                                                return InputStream::one(
-                                                    UntaggedValue::Error(err).into_untagged_value(),
-                                                )
+                                                context.error(err);
+                                                return InputStream::empty();
                                             }
                                         },
                                     ));
@@ -153,12 +147,11 @@ pub(crate) async fn run_internal_command(
                                 }
                                 _ => {
                                     context.shell_manager.insert_at_current(Box::new(
-                                        match HelpShell::index(&context.registry()) {
+                                        match HelpShell::index(&context.scope) {
                                             Ok(v) => v,
                                             Err(err) => {
-                                                return InputStream::one(
-                                                    UntaggedValue::Error(err).into_untagged_value(),
-                                                )
+                                                context.error(err);
+                                                return InputStream::empty();
                                             }
                                         },
                                     ));
@@ -176,21 +169,13 @@ pub(crate) async fn run_internal_command(
                                     match FilesystemShell::with_location(location) {
                                         Ok(v) => v,
                                         Err(err) => {
-                                            return InputStream::one(
-                                                UntaggedValue::Error(err.into())
-                                                    .into_untagged_value(),
-                                            )
+                                            context.error(err.into());
+                                            return InputStream::empty();
                                         }
                                     },
                                 ));
                                 InputStream::from_stream(futures::stream::iter(vec![]))
                             }
-                            CommandAction::AddAlias(sig, block) => {
-                                context.add_commands(vec![whole_stream_command(
-                                    AliasCommand::new(*sig, block),
-                                )]);
-                                InputStream::from_stream(futures::stream::iter(vec![]))
-                            }
                             CommandAction::AddPlugins(path) => {
                                 match crate::plugin::scan(vec![std::path::PathBuf::from(path)]) {
                                     Ok(plugins) => {
@@ -203,39 +188,37 @@ pub(crate) async fn run_internal_command(
                                                 .collect(),
                                         );
 
-                                        InputStream::from_stream(futures::stream::iter(vec![]))
+                                        InputStream::empty()
                                     }
                                     Err(reason) => {
-                                        context.error(reason.clone());
-                                        InputStream::one(
-                                            UntaggedValue::Error(reason).into_untagged_value(),
-                                        )
+                                        context.error(reason);
+                                        InputStream::empty()
                                     }
                                 }
                             }
                             CommandAction::PreviousShell => {
                                 context.shell_manager.prev();
-                                InputStream::from_stream(futures::stream::iter(vec![]))
+                                InputStream::empty()
                             }
                             CommandAction::NextShell => {
                                 context.shell_manager.next();
-                                InputStream::from_stream(futures::stream::iter(vec![]))
+                                InputStream::empty()
                             }
                             CommandAction::LeaveShell => {
                                 context.shell_manager.remove_at_current();
                                 if context.shell_manager.is_empty() {
                                     std::process::exit(0); // TODO: save history.txt
                                 }
-                                InputStream::from_stream(futures::stream::iter(vec![]))
+                                InputStream::empty()
                             }
                         },
 
                         Ok(ReturnSuccess::Value(Value {
                             value: UntaggedValue::Error(err),
-                            tag,
+                            ..
                         })) => {
-                            context.error(err.clone());
-                            InputStream::one(UntaggedValue::Error(err).into_value(tag))
+                            context.error(err);
+                            InputStream::empty()
                         }
 
                         Ok(ReturnSuccess::Value(v)) => InputStream::one(v),
@@ -255,8 +238,8 @@ pub(crate) async fn run_internal_command(
                         }
 
                         Err(err) => {
-                            context.error(err.clone());
-                            InputStream::one(UntaggedValue::Error(err).into_untagged_value())
+                            context.error(err);
+                            InputStream::empty()
                         }
                     }
                 }
