@@ -1,6 +1,5 @@
 use std::path::PathBuf;
 
-use crate::command_registry::CommandRegistry;
 use crate::commands::WholeStreamCommand;
 use crate::path::canonicalize;
 use crate::prelude::*;
@@ -43,17 +42,14 @@ impl WholeStreamCommand for SubCommand {
         vec![Example {
             description: "Load all plugins in the current directory",
             example: "nu plugin --load .",
-            result: Some(vec![]),
+            result: None,
         }]
     }
 
-    async fn run(
-        &self,
-        args: CommandArgs,
-        registry: &CommandRegistry,
-    ) -> Result<OutputStream, ShellError> {
+    async fn run(&self, args: CommandArgs) -> Result<OutputStream, ShellError> {
+        let scope = args.scope.clone();
         let shell_manager = args.shell_manager.clone();
-        let (Arguments { load_path }, _) = args.process(&registry).await?;
+        let (Arguments { load_path }, _) = args.process().await?;
 
         if let Some(Tagged {
             item: load_path,
@@ -105,7 +101,7 @@ impl WholeStreamCommand for SubCommand {
         }
 
         Ok(OutputStream::one(ReturnSuccess::value(
-            UntaggedValue::string(crate::commands::help::get_help(&SubCommand, &registry))
+            UntaggedValue::string(crate::commands::help::get_help(&SubCommand, &scope))
                 .into_value(Tag::unknown()),
         )))
     }
