@@ -12,6 +12,7 @@ use nu_errors::ShellError;
 use nu_protocol::{ColumnPath, Primitive, ReturnSuccess, ShellTypeName, UntaggedValue, Value};
 use nu_source::Span;
 use std::path::Path;
+use std::sync::Arc;
 
 pub use basename::PathBasename;
 pub use command::Path as PathCommand;
@@ -24,17 +25,32 @@ pub use r#type::PathType;
 
 #[derive(Deserialize)]
 struct DefaultArguments {
-    rest: Vec<ColumnPath>,
+    // used by basename, dirname, extension and filestem
+    replace: Option<String>,
+    // used by filestem
+    prefix: Option<String>,
+    suffix: Option<String>,
+    // used by dirname
+    num_levels: Option<u32>,
+    // used by all
+    paths: Vec<ColumnPath>,
 }
 
-fn handle_value<F>(action: &F, v: &Value, span: Span) -> Result<Value, ShellError>
+fn handle_value<F>(
+    action: &F,
+    v: &Value,
+    span: Span,
+    args: Arc<DefaultArguments>,
+) -> Result<Value, ShellError>
 where
-    F: Fn(&Path) -> UntaggedValue + Send + 'static,
+    F: Fn(&Path, Arc<DefaultArguments>) -> UntaggedValue + Send + 'static,
 {
     let v = match &v.value {
-        UntaggedValue::Primitive(Primitive::Path(buf)) => action(buf).into_value(v.tag()),
+        UntaggedValue::Primitive(Primitive::Path(buf)) => action(buf, args).into_value(v.tag()),
         UntaggedValue::Primitive(Primitive::String(s))
-        | UntaggedValue::Primitive(Primitive::Line(s)) => action(s.as_ref()).into_value(v.tag()),
+        | UntaggedValue::Primitive(Primitive::Line(s)) => {
+            action(s.as_ref(), args).into_value(v.tag())
+        }
         other => {
             let got = format!("got {}", other.type_name());
             return Err(ShellError::labeled_error_with_secondary(
@@ -51,24 +67,25 @@ where
 
 async fn operate<F>(
     input: crate::InputStream,
-    paths: Vec<ColumnPath>,
     action: &'static F,
     span: Span,
+    args: Arc<DefaultArguments>,
 ) -> Result<OutputStream, ShellError>
 where
-    F: Fn(&Path) -> UntaggedValue + Send + Sync + 'static,
+    F: Fn(&Path, Arc<DefaultArguments>) -> UntaggedValue + Send + Sync + 'static,
 {
     Ok(input
         .map(move |v| {
-            if paths.is_empty() {
-                ReturnSuccess::value(handle_value(&action, &v, span)?)
+            if args.paths.is_empty() {
+                ReturnSuccess::value(handle_value(&action, &v, span, Arc::clone(&args))?)
             } else {
                 let mut ret = v;
 
-                for path in &paths {
+                for path in &args.paths {
+                    let cloned_args = Arc::clone(&args);
                     ret = ret.swap_data_by_column_path(
                         path,
-                        Box::new(move |old| handle_value(&action, &old, span)),
+                        Box::new(move |old| handle_value(&action, &old, span, cloned_args)),
                     )?;
                 }
 
