@@ -28,13 +28,9 @@ impl WholeStreamCommand for PathType {
         "Gives the type of the object a path refers to (e.g., file, dir, symlink)"
     }
 
-    async fn run(
-        &self,
-        args: CommandArgs,
-        registry: &CommandRegistry,
-    ) -> Result<OutputStream, ShellError> {
+    async fn run(&self, args: CommandArgs) -> Result<OutputStream, ShellError> {
         let tag = args.call_info.name_tag.clone();
-        let (PathTypeArguments { rest }, input) = args.process(&registry).await?;
+        let (PathTypeArguments { rest }, input) = args.process().await?;
         let args = Arc::new(DefaultArguments {
             replace: None,
             prefix: None,
