@@ -46,22 +46,14 @@ impl WholeStreamCommand for Pivot {
         "Pivots the table contents so rows become columns and columns become rows."
     }
 
-    async fn run(
-        &self,
-        args: CommandArgs,
-        registry: &CommandRegistry,
-    ) -> Result<OutputStream, ShellError> {
-        pivot(args, registry).await
+    async fn run(&self, args: CommandArgs) -> Result<OutputStream, ShellError> {
+        pivot(args).await
     }
 }
 
-pub async fn pivot(
-    args: CommandArgs,
-    registry: &CommandRegistry,
-) -> Result<OutputStream, ShellError> {
-    let registry = registry.clone();
+pub async fn pivot(args: CommandArgs) -> Result<OutputStream, ShellError> {
     let name = args.call_info.name_tag.clone();
-    let (args, input): (PivotArgs, _) = args.process(&registry).await?;
+    let (args, input): (PivotArgs, _) = args.process().await?;
     let input = input.into_vec().await;
 
     let descs = merge_descriptors(&input);
