@@ -2,17 +2,18 @@ use crate::commands::classified::block::run_block;
 use crate::commands::each;
 use crate::commands::WholeStreamCommand;
 use crate::prelude::*;
-use crate::{CommandArgs, CommandRegistry, Example, OutputStream};
+use crate::{CommandArgs, Example, OutputStream};
 use futures::stream::once;
 use nu_errors::ShellError;
-use nu_protocol::{hir::Block, Primitive, Scope, Signature, SyntaxShape, UntaggedValue, Value};
+use nu_parser::ParserScope;
+use nu_protocol::{hir::CapturedBlock, Signature, SyntaxShape, UntaggedValue, Value};
 use nu_source::Tagged;
 
 pub struct Reduce;
 
 #[derive(Deserialize)]
 pub struct ReduceArgs {
-    block: Block,
+    block: CapturedBlock,
     fold: Option<Value>,
     numbered: Tagged<bool>,
 }
@@ -44,12 +45,8 @@ impl WholeStreamCommand for Reduce {
         (A, A) -> A unless --fold is selected, in which case it may be A, B -> A."
     }
 
-    async fn run(
-        &self,
-        args: CommandArgs,
-        registry: &CommandRegistry,
-    ) -> Result<OutputStream, ShellError> {
-        reduce(args, registry).await
+    async fn run(&self, args: CommandArgs) -> Result<OutputStream, ShellError> {
+        reduce(args).await
     }
 
     fn examples(&self) -> Vec<Example> {
@@ -79,41 +76,42 @@ impl WholeStreamCommand for Reduce {
 }
 
 async fn process_row(
-    block: Arc<Block>,
-    scope: Arc<Scope>,
-    mut context: Arc<EvaluationContext>,
+    block: Arc<CapturedBlock>,
+    context: &EvaluationContext,
     row: Value,
 ) -> Result<InputStream, ShellError> {
     let row_clone = row.clone();
     let input_stream = once(async { Ok(row_clone) }).to_input_stream();
 
-    let scope = Scope::append_var(scope, "$it", row);
+    context.scope.enter_scope();
+    context.scope.add_vars(&block.captured.entries);
+    context.scope.add_var("$it", row);
+    let result = run_block(&block.block, context, input_stream).await;
+    context.scope.exit_scope();
 
-    Ok(run_block(&block, Arc::make_mut(&mut context), input_stream, scope).await?)
+    Ok(result?)
 }
 
-async fn reduce(
-    raw_args: CommandArgs,
-    registry: &CommandRegistry,
-) -> Result<OutputStream, ShellError> {
-    let registry = registry.clone();
-    let base_scope = raw_args.call_info.scope.clone();
-    let context = Arc::new(EvaluationContext::from_raw(&raw_args, &registry));
-    let (reduce_args, mut input): (ReduceArgs, _) = raw_args.process(&registry).await?;
+async fn reduce(raw_args: CommandArgs) -> Result<OutputStream, ShellError> {
+    let span = raw_args.call_info.name_tag.span;
+    let context = Arc::new(EvaluationContext::from_raw(&raw_args));
+    let (reduce_args, mut input): (ReduceArgs, _) = raw_args.process().await?;
     let block = Arc::new(reduce_args.block);
-    let (ioffset, start) = match reduce_args.fold {
-        None => {
-            let first = input
-                .next()
-                .await
-                .expect("empty stream expected to contain Primitive::Nothing");
-            if let UntaggedValue::Primitive(Primitive::Nothing) = first.value {
-                return Err(ShellError::missing_value(None, "empty input"));
-            }
+    let (ioffset, start) = if !input.is_empty() {
+        match reduce_args.fold {
+            None => {
+                let first = input.next().await.expect("non-empty stream");
 
-            (1, first)
+                (1, first)
+            }
+            Some(acc) => (0, acc),
         }
-        Some(acc) => (0, acc),
+    } else {
+        return Err(ShellError::labeled_error(
+            "Expected input",
+            "needs input",
+            span,
+        ));
     };
 
     if reduce_args.numbered.item {
@@ -126,12 +124,11 @@ async fn reduce(
         Ok(input
             .enumerate()
             .fold(initial, move |acc, input| {
+                let context = context.clone();
                 let block = Arc::clone(&block);
-                let scope = base_scope.clone();
-                let context = Arc::clone(&context);
                 let row = each::make_indexed_item(input.0 + ioffset, input.1);
 
-                async {
+                async move {
                     let values = acc?.drain_vec().await;
 
                     let f = if values.len() == 1 {
@@ -145,8 +142,12 @@ async fn reduce(
                         UntaggedValue::table(&values).into_untagged_value()
                     };
 
-                    let scope = Scope::append_var(scope, "$acc", f);
-                    process_row(block, scope, context, row).await
+                    context.scope.enter_scope();
+                    context.scope.add_var("$acc", f);
+                    let result = process_row(block, &*context, row).await;
+                    context.scope.exit_scope();
+
+                    result
                 }
             })
             .await?
@@ -156,10 +157,9 @@ async fn reduce(
         Ok(input
             .fold(initial, move |acc, row| {
                 let block = Arc::clone(&block);
-                let scope = base_scope.clone();
-                let context = Arc::clone(&context);
+                let context = context.clone();
 
-                async {
+                async move {
                     let values = acc?.drain_vec().await;
 
                     let f = if values.len() == 1 {
@@ -173,8 +173,11 @@ async fn reduce(
                         UntaggedValue::table(&values).into_untagged_value()
                     };
 
-                    let scope = Scope::append_var(scope, "$acc", f);
-                    process_row(block, scope, context, row).await
+                    context.scope.enter_scope();
+                    context.scope.add_var("$acc", f);
+                    let result = process_row(block, &*context, row).await;
+                    context.scope.exit_scope();
+                    result
                 }
             })
             .await?
