@@ -33,12 +33,8 @@ impl WholeStreamCommand for Rename {
         "Creates a new table with columns renamed."
     }
 
-    async fn run(
-        &self,
-        args: CommandArgs,
-        registry: &CommandRegistry,
-    ) -> Result<OutputStream, ShellError> {
-        rename(args, registry).await
+    async fn run(&self, args: CommandArgs) -> Result<OutputStream, ShellError> {
+        rename(args).await
     }
 
     fn examples(&self) -> Vec<Example> {
@@ -66,13 +62,9 @@ impl WholeStreamCommand for Rename {
     }
 }
 
-pub async fn rename(
-    args: CommandArgs,
-    registry: &CommandRegistry,
-) -> Result<OutputStream, ShellError> {
-    let registry = registry.clone();
+pub async fn rename(args: CommandArgs) -> Result<OutputStream, ShellError> {
     let name = args.call_info.name_tag.clone();
-    let (Arguments { column_name, rest }, input) = args.process(&registry).await?;
+    let (Arguments { column_name, rest }, input) = args.process().await?;
     let mut new_column_names = vec![vec![column_name]];
     new_column_names.push(rest);
 
