@@ -31,22 +31,14 @@ impl WholeStreamCommand for SplitBy {
         "Creates a new table with the data from the inner tables split by the column given."
     }
 
-    async fn run(
-        &self,
-        args: CommandArgs,
-        registry: &CommandRegistry,
-    ) -> Result<OutputStream, ShellError> {
-        split_by(args, registry).await
+    async fn run(&self, args: CommandArgs) -> Result<OutputStream, ShellError> {
+        split_by(args).await
     }
 }
 
-pub async fn split_by(
-    args: CommandArgs,
-    registry: &CommandRegistry,
-) -> Result<OutputStream, ShellError> {
-    let registry = registry.clone();
+pub async fn split_by(args: CommandArgs) -> Result<OutputStream, ShellError> {
     let name = args.call_info.name_tag.clone();
-    let (SplitByArgs { column_name }, input) = args.process(&registry).await?;
+    let (SplitByArgs { column_name }, input) = args.process().await?;
     let values: Vec<Value> = input.collect().await;
 
     if values.len() > 1 || values.is_empty() {
