@@ -37,12 +37,8 @@ impl WholeStreamCommand for SubCommand {
         "Checks if string contains pattern"
     }
 
-    async fn run(
-        &self,
-        args: CommandArgs,
-        registry: &CommandRegistry,
-    ) -> Result<OutputStream, ShellError> {
-        operate(args, registry).await
+    async fn run(&self, args: CommandArgs) -> Result<OutputStream, ShellError> {
+        operate(args).await
     }
 
     fn examples(&self) -> Vec<Example> {
@@ -61,12 +57,7 @@ impl WholeStreamCommand for SubCommand {
     }
 }
 
-async fn operate(
-    args: CommandArgs,
-    registry: &CommandRegistry,
-) -> Result<OutputStream, ShellError> {
-    let registry = registry.clone();
-
+async fn operate(args: CommandArgs) -> Result<OutputStream, ShellError> {
     let (
         Arguments {
             pattern,
@@ -74,7 +65,7 @@ async fn operate(
             insensitive,
         },
         input,
-    ) = args.process(&registry).await?;
+    ) = args.process().await?;
     let column_paths: Vec<_> = rest;
 
     Ok(input
