@@ -42,12 +42,8 @@ impl WholeStreamCommand for SubCommand {
         "pad a string with a character a certain length"
     }
 
-    async fn run(
-        &self,
-        args: CommandArgs,
-        registry: &CommandRegistry,
-    ) -> Result<OutputStream, ShellError> {
-        operate(args, registry).await
+    async fn run(&self, args: CommandArgs) -> Result<OutputStream, ShellError> {
+        operate(args).await
     }
 
     fn examples(&self) -> Vec<Example> {
@@ -75,12 +71,7 @@ impl WholeStreamCommand for SubCommand {
     }
 }
 
-async fn operate(
-    args: CommandArgs,
-    registry: &CommandRegistry,
-) -> Result<OutputStream, ShellError> {
-    let registry = registry.clone();
-
+async fn operate(args: CommandArgs) -> Result<OutputStream, ShellError> {
     let (
         Arguments {
             length,
@@ -88,7 +79,7 @@ async fn operate(
             rest,
         },
         input,
-    ) = args.process(&registry).await?;
+    ) = args.process().await?;
     let column_paths: Vec<_> = rest;
 
     Ok(input
