@@ -9,7 +9,9 @@ mod find_replace;
 pub mod from;
 mod index_of;
 mod length;
+mod lpad;
 mod reverse;
+mod rpad;
 mod set;
 mod starts_with;
 mod substring;
@@ -34,7 +36,9 @@ pub use find_replace::SubCommand as StrFindReplace;
 pub use from::SubCommand as StrFrom;
 pub use index_of::SubCommand as StrIndexOf;
 pub use length::SubCommand as StrLength;
+pub use lpad::SubCommand as StrLPad;
 pub use reverse::SubCommand as StrReverse;
+pub use rpad::SubCommand as StrRPad;
 pub use set::SubCommand as StrSet;
 pub use starts_with::SubCommand as StrStartsWith;
 pub use substring::SubCommand as StrSubstring;
