@@ -7,7 +7,6 @@ use quick_xml::events::{BytesEnd, BytesStart, BytesText, Event};
 use std::collections::HashSet;
 use std::io::Cursor;
 use std::io::Write;
-use std::iter::FromIterator;
 
 pub struct ToXML;
 
@@ -35,12 +34,8 @@ impl WholeStreamCommand for ToXML {
         "Convert table into .xml text"
     }
 
-    async fn run(
-        &self,
-        args: CommandArgs,
-        registry: &CommandRegistry,
-    ) -> Result<OutputStream, ShellError> {
-        to_xml(args, registry).await
+    async fn run(&self, args: CommandArgs) -> Result<OutputStream, ShellError> {
+        to_xml(args).await
     }
 }
 
@@ -81,7 +76,7 @@ pub fn get_children(row: &Value) -> Option<&Vec<Value>> {
 
 pub fn is_xml_row(row: &Value) -> bool {
     if let UntaggedValue::Row(r) = &row.value {
-        let keys: HashSet<&String> = HashSet::from_iter(r.keys());
+        let keys: HashSet<&String> = r.keys().collect();
         let children: String = "children".to_string();
         let attributes: String = "attributes".to_string();
         return keys.contains(&children) && keys.contains(&attributes) && keys.len() == 2;
@@ -137,11 +132,10 @@ pub fn write_xml_events<W: Write>(
     Ok(())
 }
 
-async fn to_xml(args: CommandArgs, registry: &CommandRegistry) -> Result<OutputStream, ShellError> {
-    let registry = registry.clone();
+async fn to_xml(args: CommandArgs) -> Result<OutputStream, ShellError> {
     let name_tag = args.call_info.name_tag.clone();
     let name_span = name_tag.span;
-    let (ToXMLArgs { pretty }, input) = args.process(&registry).await?;
+    let (ToXMLArgs { pretty }, input) = args.process().await?;
     let input: Vec<Value> = input.collect().await;
 
     let to_process_input = match input.len() {
